netapp_ontap.models.data_engine_governance_policies_guardrail_conditions API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_engine_governance_policies_guardrail_conditions`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataEngineGovernancePoliciesGuardrailConditionsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataEngineGovernancePoliciesGuardrailConditions object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `items: List[str] GET POST PATCH`

    List of classifier or category tags associated with the condition.

  `operator: str GET POST PATCH`

    specifies operator for condition. Possible values are:

    - all: All conditions must be met.
    - any: Any one of the conditions must be met.

    Valid choices:

    - all
    - any
  `type: str GET POST PATCH`

    specifies type of condition. Possible values are:

    - data_classifier_category: Condition based on data classifier category.
    - document_classifier_category: Condition based on document classifier category.
    - data_classifier: Condition based on data classifier.
    - document_classifier: Condition based on document classifier.

    Valid choices:

    - data_classifier_category
    - document_classifier_category
    - data_classifier
    - document_classifier